@@ -1,10 +1,10 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
-version: 1.3.3
-id: authenticate-1.3.3-737b5333b0b8f4ef94111663d9d22000
-key: authe_0MA6DvnrNIS2Mu488OU37l
-license: BSD3
+version: 1.3.3.1
+id: authenticate-1.3.3.1-de5806f9d15beccb070a770364a3018e
+key: authe_HGus0ePTHs6JUjzx5oAJ1H
+license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
 homepage: http://github.com/yesodweb/authenticate
@@ -20,29 +20,29 @@ exposed-modules:
 hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                 OpenId2.Normalization OpenId2.Types OpenId2.XRDS
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
-hs-libraries: HSauthenticate-1.3.3-0MA6DvnrNIS2Mu488OU37l
+import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3.1
+hs-libraries: HSauthenticate-1.3.3.1-HGus0ePTHs6JUjzx5oAJ1H
 depends:
-    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
-    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
-    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.8-27d1393c2c1993a0373ed4eef1793cf2
-    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
-    monad-control-1.0.0.4-fa18b603f1c859e06ea8fbebdf00a3e7
-    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
-    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
-    tagstream-conduit-0.5.5.3-a5374a0f8ba6347b0d56f4690846feac
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    http-conduit-2.1.9-a114e1e30c63561e9380f63d9f83e5a8
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
+    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
+    tagstream-conduit-0.5.5.3-263ed71b63ed196273744e4745b0360d
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
-    xml-conduit-1.3.3-015e9953b0f75ba36e24f916204128dc
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
+    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
